@@ -5,9 +5,9 @@ from aurora import Model
 class ModelName(Model):
 
     # Model columns
-    id = Model.column(datatype='integer')
+    id = Model.column(datatype='integer', not_null=True)
 
-    # Model meta data
+    # Model constructor
     def __init__(self):
         # Inherit the parent class
         super().__init__()
