@@ -10,9 +10,8 @@ except:
     pass
 
 View = Template().render
-Error = Template().render_error
 
 
 # Descriptions
-__version__ = '0.5.3'
-__author__ = 'Hemin Satya <https://github.com/heminsatya>'
+__version__ = '0.6.1'
+__author__ = '<https://github.com/heminsatya>'
